@@ -7,6 +7,8 @@ from abc import ABC
 from struct import calcsize, unpack
 
 import pandas as pd
+from pytdx.hq import TdxHq_API
+from unipath import Path
 
 from mootdx import config
 from mootdx.config import settings
@@ -17,7 +19,7 @@ class FinancialReader(BaseReader, ABC):
     @staticmethod
     def to_data(filename):
         """
-        读取历史财务数据文件，并返回pandas结果 ， 类似gpcw20171231.zip格式，具体字段含义参考
+        读取历史财务数据文件，并返回pandas结果 ， 类似 `gpcw20171231.zip` 格式，具体字段含义参考
 
         https://github.com/rainx/pytdx/issues/133
 
@@ -39,7 +41,7 @@ class FinancialList(BaseFinancial):
     # def __init__(self, *args, **kwargs):
     #     super().__init__(*args, **kwargs)
 
-    def url(self, *args, **kwargs):
+    def build_url(self, *args, **kwargs):
         """
         获取采集数据的 URL
 
@@ -51,13 +53,7 @@ class FinancialList(BaseFinancial):
         # return 'http://down.tdx.com.cn:8001/fin/gpcw.txt'
         # return 'http://data.yutiansut.com/content.txt'
 
-    def content(self,
-                report_hook=None,
-                downdir=None,
-                proxies=None,
-                chunk_size=1024 * 50,
-                *args,
-                **kwargs):
+    def content(self, report_hook=None, downdir=None, proxies=None, chunk_size=1024 * 50, *args, **kwargs):
         """
         解析财务文件
 
@@ -105,17 +101,11 @@ class FinancialList(BaseFinancial):
         content = download_file.read()
         content = content.decode("utf-8")
 
-        def list_to_dict(l):
-            return {'filename': l[0], 'hash': l[1], 'filesize': int(l[2])}
+        def list_to_dict(i):
+            return {'filename': i[0], 'hash': i[1], 'filesize': int(i[2])}
 
         if content:
-            result = [
-                list_to_dict(l) for l in [
-                    line.strip().split(",")
-                    for line in content.strip().split('\n')
-                ]
-            ]
-            return result
+            return [list_to_dict(i) for i in [line.strip().split(",") for line in content.strip().split('\n')]]
 
         return None
 
@@ -126,7 +116,7 @@ class Financial(BaseFinancial):
     def __init__(self):
         super().__init__()
 
-    def url(self, *args, **kwargs):
+    def build_url(self, *args, **kwargs):
         """
         获取采集数据的 URL
 
@@ -140,17 +130,11 @@ class Financial(BaseFinancial):
             raise Exception("Param filename is not set")
 
         # log.debug(f"http://down.tdx.com.cn:8001/fin/{filename}")
-
         # return "http://data.yutiansut.com/{}".format(filename)
+
         return "http://down.tdx.com.cn:8001/fin/{}".format(filename)
 
-    def content(self,
-                report_hook=None,
-                downdir=None,
-                proxies=None,
-                chunk_size=1024 * 50,
-                *args,
-                **kwargs):
+    def content(self, report_hook=None, downdir=None, proxies=None, chunk_size=1024 * 50, *args, **kwargs):
         """
         解析财务文件
 
@@ -168,8 +152,6 @@ class Financial(BaseFinancial):
         if not filename:
             raise Exception("Param filename is not set")
 
-        from pytdx.hq import TdxHq_API
-
         api = TdxHq_API()
         api.need_setup = False
 
@@ -180,12 +162,8 @@ class Financial(BaseFinancial):
             bestip = ("106.14.95.149", 7727)
 
         with api.connect(*bestip):
-            content = api.get_report_file_by_size(f"tdxfin/{filename}",
-                                                  filesize=filesize,
-                                                  reporthook=report_hook)
-            download_file = open(
-                downdir, 'wb') if downdir else tempfile.NamedTemporaryFile(
-                delete=True)
+            content = api.get_report_file_by_size(f"tdxfin/{filename}", filesize=filesize, reporthook=report_hook)
+            download_file = open(downdir, 'wb') if downdir else tempfile.NamedTemporaryFile(delete=True)
             download_file.write(content)
             download_file.seek(0)
 
@@ -208,7 +186,7 @@ class Financial(BaseFinancial):
             tmpdir_root = tempfile.gettempdir()
             subdir_name = "mootdx_{}".format(str(random.randint(0, 1000000)))
 
-            tmpdir = os.path.join(tmpdir_root, subdir_name)
+            tmpdir = Path(tmpdir_root, subdir_name)
             shutil.rmtree(tmpdir, ignore_errors=True)
             os.makedirs(tmpdir)
 
@@ -219,7 +197,7 @@ class Financial(BaseFinancial):
 
             for _file in os.listdir(tmpdir):
                 if _file.endswith(".dat"):
-                    datfile = open(os.path.join(tmpdir, _file), "rb")
+                    datfile = open(Path(tmpdir, _file), "rb")
 
             if datfile is None:
                 raise Exception("no dat file found in zip archive")
@@ -270,15 +248,10 @@ class Financial(BaseFinancial):
         if len(data) == 0:
             return None
 
-        total_lengh = len(data[0])
-        col = ['code', 'report_date']
-
-        length = total_lengh - 1
+        column = ['code', 'report_date']
+        length = len(data[0]) - 1
 
         for i in range(1, length):
-            col.append("col" + str(i))
+            column.append("col" + str(i))
 
-        df = pd.DataFrame(data=data, columns=col)
-        df.set_index('code', inplace=True)
-
-        return df
+        return pd.DataFrame(data=data, columns=column).set_index('code', inplace=True)
